summaryrefslogtreecommitdiff
path: root/src/include/taler_util.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/taler_util.h')
-rw-r--r--src/include/taler_util.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/include/taler_util.h b/src/include/taler_util.h
index 58b1906c2..3f5935728 100644
--- a/src/include/taler_util.h
+++ b/src/include/taler_util.h
@@ -237,13 +237,13 @@ TALER_url_absolute_mhd (struct MHD_Connection *connection,
/**
* Obtain the payment method from a @a payto_url
*
* @param payto_url the URL to parse
* @return NULL on error (malformed @a payto_url)
*/
char *
-TALER_payto_get_method (const char *payto_url);
+TALER_payto_get_method (const char *payto_uri);
/**
@@ -237,13 +237,13 @@ TALER_url_absolute_mhd (struct MHD_Connection *connection,
/**
- * Obtain the payment method from a @a payto_url
+ * Obtain the payment method from a @a payto_uri
*
@@ -237,13 +237,13 @@ TALER_url_absolute_mhd (struct MHD_Connection *connection,
*
- * @param payto_url the URL to parse
- * @return NULL on error (malformed @a payto_url)
+ * @param payto_uri the URL to parse
+ * @return NULL on error (malformed @a payto_uri)
*/
char *